@@ -10,7 +10,6 @@
 #include <QDebug>
 #include <QDir>
 #include <QMessageBox>
-#include <QSettings>
 #include <QSqlDatabase>
 #include <QSqlError>
 #include <QSqlQuery>
@@ -19,6 +18,7 @@
 #include "entities/calendaritem.h"
 #include "mainwindow.h"
 #include "owncloudservice.h"
+#include "services/settingsservice.h"
 
 DatabaseService::DatabaseService() = default;
 
@@ -401,7 +401,7 @@ void DatabaseService::closeDatabaseConnection(QSqlDatabase& db, QSqlQuery& query
 bool DatabaseService::setupTables() {
     QSqlDatabase dbDisk = QSqlDatabase::database(QStringLiteral("disk"));
     QSqlQuery queryDisk(dbDisk);
-    QSettings settings;
+    SettingsService settings;
 
     queryDisk.exec(
         QStringLiteral("CREATE TABLE IF NOT EXISTS appData ("
