@@ -99,7 +99,7 @@ void QOwnNotesMarkdownTextEdit::onZoom(bool in) {
     const int fontSize = modifyFontSize(mode);
 
     auto mainWindow = MainWindow::instance();
-    if (mainWindow && mainWindow->isInDistractionFreeMode()) {
+    if (mainWindow && MainWindow::isInDistractionFreeMode()) {
         setPaperMargins();
         if (in) {
             mainWindow->showStatusBarMessage(tr("Increased font size to %1 pt").arg(fontSize),
@@ -109,6 +109,8 @@ void QOwnNotesMarkdownTextEdit::onZoom(bool in) {
                                              3000);
         }
     }
+
+    setPaperMargins();
 }
 
 /**
@@ -393,7 +395,7 @@ void QOwnNotesMarkdownTextEdit::setPaperMargins(int width) {
                 // set the size of characterAmount times the size of "O"
                 // characters
 #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
-            int proposedEditorWidth = metrics.width(QString("O").repeated(characterAmount));
+            int proposedEditorWidth = metrics.width(QStringLiteral("O").repeated(characterAmount));
 #else
             int proposedEditorWidth =
                 metrics.horizontalAdvance(QStringLiteral("O").repeated(characterAmount));
@@ -904,7 +906,9 @@ void QOwnNotesMarkdownTextEdit::onContextMenu(QPoint pos) {
 
     if (isTextSelected) {
         menu->addAction(MainWindow::instance()->searchTextOnWebAction());
+        menu->addAction(MainWindow::instance()->findNoteAction());
     }
+
     //     searchAction->setEnabled(isTextSelected);
     //     QAction *searchAction =
     //         menu->addAction(ui->actionSearch_text_on_the_web->text());
